@@ -513,6 +513,8 @@ class Users(_defaults_.Defaults):
 		# html colors.
 		for key,value in self.template_data["COLORS"].items():
 			html = html.replace(f"(${key.upper()})", str(value))
+		print("HTML:")
+		print(html)
 
 		# send email.
 		if Defaults.options.log_level >= 1:
